summaryrefslogtreecommitdiff
path: root/geneticone/gui/gtk/wrapper.py
diff options
context:
space:
mode:
Diffstat (limited to 'geneticone/gui/gtk/wrapper.py')
-rw-r--r--geneticone/gui/gtk/wrapper.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/geneticone/gui/gtk/wrapper.py b/geneticone/gui/gtk/wrapper.py
index 7597a8a..7066acb 100644
--- a/geneticone/gui/gtk/wrapper.py
+++ b/geneticone/gui/gtk/wrapper.py
@@ -1,7 +1,7 @@
# -*- coding: utf-8 -*-
#
# File: geneticone/gui/gtk/wrapper.py
# This file is part of the Genetic/One-Project, a graphical portage-frontend.
#
# Copyright (C) 2006 René 'Necoro' Neumann
# This is free software. You may redistribute copies of it under the terms of
@@ -10,7 +10,7 @@
#
# Written by René 'Necoro' Neumann <necoro@necoro.net>
-from geneticone.gui.wrapper import Tree, Console
+from portato.gui.wrapper import Tree, Console
class GtkTree (Tree):
"""The implementation of the abstract tree."""
@@ -1,7 +1,7 @@
# -*- coding: utf-8 -*-
#
-# File: geneticone/gui/gtk/wrapper.py
-# This file is part of the Genetic/One-Project, a graphical portage-frontend.
+# File: portato/gui/gtk/wrapper.py
+# This file is part of the Portato-Project, a graphical portage-frontend.
#
# Copyright (C) 2006 René 'Necoro' Neumann